@@ -122,7 +122,7 @@ class App:
     async def __call__(self, scope, recieve, send):
         if "static" in scope["path"]:
             # await self.static_app(scope, recieve, send)
-            return StaticFile(scope["path"])
+            await StaticFile(scope["path"])
 
         await self.middleware(scope, recieve, send)
 
