@@ -6,5 +6,5 @@ class StaticFile:
     def __init__(self, directory):
         self.directory = directory
     
-    async def __call__(self, path):
+    async def __call__(self, path: str):
         return FileResponse(path)
\ No newline at end of file
